==> mdk-0.1.1.tar.gz: mdk-0.1.1/mixlib/mix.c <==
/* -*-c-*- -------------- mix.c :
 * Implementation of the functions declared in mix.h
 * ------------------------------------------------------------------
 * Copyright (C) 2000 jose antonio ortega ruiz <jaortega@acm.org>
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 */


#include "mix_types.h"
#include "mix_ins.h"
#include "mix_code_file.h"
#include "mix.h"


/* This function must be called before using the library */
void 
mix_init_lib(void)
{
  mix_init_types ();
  mix_init_ins ();
  mix_code_file_set_defext (MIX_CODE_DEFEXT);
}


/* This function must be called for deallocating the lib resources
   when it is no longer in use 
*/
void
mix_release_lib (void)
{
  /* clean the user defined code file extension (if any) */
  mix_code_file_set_defext (NULL); 
  mix_release_ins ();
}

const char *MIX_GPL_LICENSE = 
"Copyright (C) 2000 jose antonio ortega ruiz <jaortega@acm.org>\n" 
"This program is free software; you can redistribute it and/or modify\n"
"it under the terms of the GNU General Public License as published by\n"
"the Free Software Foundation; either version 2 of the License, or\n"
"(at your option) any later version.\n"
"This program is distributed in the hope that it will be useful,\n"
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
"GNU General Public License for more details.\n"
"You should have received a copy of the GNU General Public License\n"
"along with this program; if not, write to the Free Software\n"
"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n";

==> mdk-0.3.1.tar.gz: mdk-0.3.1/mixlib/mix.c <==
/* -*-c-*- -------------- mix.c :
 * Implementation of the functions declared in mix.h
 * ------------------------------------------------------------------
 * Copyright (C) 2000 Free Software Foundation, Inc.
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *  
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *  
 */


#include "mix_types.h"
#include "mix_ins.h"
#include "mix_code_file.h"
#include "mix.h"


/* This function must be called before using the library */
void 
mix_init_lib(void)
{
  mix_init_types ();
  mix_init_ins ();
  mix_code_file_set_defext (MIX_CODE_DEFEXT);
}


/* This function must be called for deallocating the lib resources
   when it is no longer in use 
*/
void
mix_release_lib (void)
{
  /* clean the user defined code file extension (if any) */
  mix_code_file_set_defext (NULL); 
  mix_release_ins ();
}

const char *MIX_GPL_LICENSE = 
"Copyright (C) 2000, 2001 Free Software Foundation, Inc.\n" 
"GNU MDK is free software; you can redistribute it and/or modify\n"
"it under the terms of the GNU General Public License as published by\n"
"the Free Software Foundation; either version 2 of the License, or\n"
"(at your option) any later version.\n"
"GNU MDK is distributed in the hope that it will be useful,\n"
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
"GNU General Public License for more details.\n"
"You should have received a copy of the GNU General Public License\n"
"along with this program; if not, write to the Free Software\n"
"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n";
